@@ -41,8 +41,9 @@ class Site(Site):
 
     def setup_features(self):
         super().setup_features()
-        self.features.define_feature(
-            "cms_functionality", _("Public web content"), activate=True)
+        self.define_feature("cms_functionality", enabled=True)
+        # self.features.define_feature(
+        #     "cms_functionality", _("Public web content"), activate=True)
 
     def get_installed_apps(self):
         """Implements :meth:`lino.core.site.Site.get_installed_apps` for Lino
@@ -104,7 +105,7 @@ class Site(Site):
         yield 'lino_xl.lib.invoicing'
         yield 'lino_xl.lib.orders'
 
-        if self.features.has_feature('cms_functionality'):
+        if self.has_feature('cms_functionality'):
             yield 'lino_xl.lib.pages'
             yield 'lino.modlib.publisher'
 
