@@ -1,11 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2017 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
-"""Fixtures specific for the Team variant of Lino Noi.
+# Copyright 2016-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
+"""Lino Noi extension of :mod:`lino_xl.lib.tickets`.
 
 """
 
 from lino_xl.lib.tickets import *
+from lino.api import _
 
 class Plugin(Plugin):
 
@@ -35,3 +36,10 @@ class Plugin(Plugin):
             yield self.site.models.tickets.MyTicketsNeedingFeedback
             # else:
             #     yield self.site.models.tickets.   PublicTickets
+
+    def setup_quicklinks(self, tb):
+        tb.add_action('tickets.RefTickets')
+        tb.add_action('tickets.ActiveTickets')
+        tb.add_action('tickets.AllTickets')
+        tb.add_action("tickets.AllTickets.insert",
+            label=_("Submit new ticket"), icon_name=None)
