@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2021 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Database models specific for Lino Noi.
@@ -9,6 +9,7 @@ Defines a customized :class:`TicketDetail`.
 """
 
 from lino.api import _
+from lino.mixins.sequenced import Hierarchical
 from lino.modlib.users.mixins import Assignable
 from lino.modlib.summaries.mixins import Summarized
 from lino_xl.lib.tickets.models import *
@@ -51,7 +52,7 @@ class Site(Site):
     #    rt.models.tickets.Subscription.objects.create(user=ar.get_user(), site=self)
 
 
-class Ticket(Ticket, Assignable, Summarized, ElasticSearchable):
+class Ticket(Ticket, Assignable, Summarized, Hierarchical, ElasticSearchable):
 
     class Meta(Ticket.Meta):
         # app_label = 'tickets'
@@ -294,6 +295,7 @@ class TicketDetail(TicketDetail):
     general1:30 general2:30 general3:30
     """, label=_("General"))
 
+
     # 50+6=56
     # in XL: label span is 4, so we have 8 units for the fields
     # 56.0/8 = 7
@@ -330,25 +332,27 @@ class TicketDetail(TicketDetail):
     # """, label=_("History"), required_roles=dd.login_required(Triager))
 
     more1 = """
-    state
-    assigned_to
-    duplicate_of
+    id:6 ref
+    summary
     # standby feedback closed
-    uploads.UploadsByController
+    parent
+    TicketsByParent
     """
 
     more2 = """
     description
     upgrade_notes
-    tickets.CheckListItemsByTicket
+    uploads.UploadsByController
+    # tickets.CheckListItemsByTicket
     """
 
     more3 = """
-    id:6 ref
-    summary
+    state
+    assigned_to
     user created
     modified fixed_since
-    DuplicatesByTicket:20 #WishesByTicket
+    duplicate_of
+    DuplicatesByTicket:20
     """
 
     # more1 = """
@@ -450,4 +454,11 @@ AllSites.column_names = "ref name company group remark workflow_buttons id *"
 
 
 # Not needed, have it be inffered by mobile_columns or tablet_columns if both None, use normal grid.
-#AllTickets.display_mode = "responsive_grid"
+#AllTickets.display_mode_main = "responsive_grid"
+
+class TicketsByParent(Tickets):
+    required_roles = dd.login_required(Reporter)
+    # label = _("Known problems")
+    master_key = 'parent'
+    column_names = "priority overview:50 quick_assign_to #ticket_type #workflow_buttons *"
+    details_of_master_template = _("Children of %(master)s")
