@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2019 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """The default :attr:`workflows_module
 <lino.core.site.Site.workflows_module>` for :ref:`noi` applications.
@@ -16,7 +16,6 @@ block, otherwise we use the more widely supported symbols from
 <http://www.fileformat.info/info/unicode/block/miscellaneous_symbols/list.htm>`__.
 
 """
-from __future__ import unicode_literals
 
 from lino.api import dd, rt, _, pgettext
 
@@ -32,6 +31,7 @@ class TicketAction(dd.ChangeStateAction):
 
     """
     needs_site = False
+    readonly = True
 
     def get_action_permission(self, ar, obj, state):
         me = ar.get_user()
@@ -43,7 +43,7 @@ class TicketAction(dd.ChangeStateAction):
         return super(TicketAction,
                      self).get_action_permission(ar, obj, state)
 
-    
+
 class MarkTicketOpened(TicketAction):
     """Mark this ticket as open.
     """
@@ -56,8 +56,8 @@ class MarkTicketOpened(TicketAction):
     #     subject = _("{user} opened {ticket}.").format(
     #         user=ar.get_user(), ticket=obj)
     #     return subject
-    
-    
+
+
 class MarkTicketWorking(TicketAction):
     """Mark this ticket as working.
     """
@@ -66,13 +66,13 @@ class MarkTicketWorking(TicketAction):
     required_states = 'new talk opened'
     needs_site = True
 
-    
+
 class MarkTicketReady(TicketAction):
     """Mark this ticket as ready.
     """
     action_name = 'mark_ready'
     required_states = "new opened working talk"
-    
+
 class MarkTicketClosed(TicketAction):
     """Mark this ticket as closed.
     """
@@ -120,4 +120,3 @@ TicketStates.cancelled.add_transition(MarkTicketRefused)
 # TicketStates.favorite_states = (TicketStates.sticky, )
 # TicketStates.work_states = (TicketStates.todo, TicketStates.new)
 # TicketStates.waiting_states = (TicketStates.done, )
-
