@@ -4,9 +4,17 @@
 
 # $ python setup.py test -s tests.test_packages
 
+ATELIER_INFO = dict(
+    nickname="noi",
+    verbose_name="Lino Noi",
+    # srcref_url='https://gitlab.com/lino-framework/cosi/blob/master/%s',
+    intersphinx_urls = dict(
+        docs="https://noi.lino-framework.org"))
+
+
 SETUP_INFO = dict(
     name='lino-noi',
-    version='22.5.0',
+    version='22.8.0',
     install_requires=['lino-xl'],
     # tests_require=['pytest', 'mock'],
     test_suite='tests',
